# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,CalibratedAges)
S3method(as.data.frame,CalibratedIntervals)
S3method(as.data.frame,ProxyRecord)
S3method(as.data.frame,RECE)
S3method(as.list,CalibratedIntervals)
S3method(labels,CalibratedAges)
S3method(mean,CalibratedAges)
S3method(mean,ProxyRecord)
S3method(median,CalibratedAges)
S3method(plot,CalibratedAges)
S3method(plot,CalibratedSPD)
S3method(plot,ProxyRecord)
S3method(plot,RECE)
S3method(quantile,CalibratedAges)
S3method(quantile,ProxyRecord)
export(pb_age)
exportMethods("[")
exportMethods(BP14C_to_F14C)
exportMethods(F14C_to_BP14C)
exportMethods(as.data.frame)
exportMethods(as.list)
exportMethods(c14_calibrate)
exportMethods(c14_combine)
exportMethods(c14_curve)
exportMethods(c14_ensemble)
exportMethods(c14_sample)
exportMethods(c14_spd)
exportMethods(c14_uncalibrate)
exportMethods(describe)
exportMethods(interval_credible)
exportMethods(interval_hdr)
exportMethods(labels)
exportMethods(mean)
exportMethods(median)
exportMethods(pb_age)
exportMethods(plot)
exportMethods(proxy_ensemble)
exportMethods(quantile)
import(aion)
import(arkhe)
importClassesFrom(aion,RataDie)
importClassesFrom(aion,TimeSeries)
importFrom(methods,.valueClassTest)
importFrom(methods,as)
importFrom(methods,new)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setValidity)
importMethodsFrom(arkhe,describe)
importMethodsFrom(arkhe,interval_credible)
importMethodsFrom(arkhe,interval_hdr)
