% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R
\docType{methods}
\name{mutators}
\alias{mutators}
\alias{get}
\alias{set}
\title{Get or Set Parts of an Object}
\arguments{
\item{x}{An object from which to get or set element(s).}

\item{value}{A possible value for the element(s) of \code{x}.}
}
\value{
An object of the same sort as \code{x} with the new values assigned.
}
\description{
Getters and setters to extract or replace parts of an object.
}
\seealso{
Other mutators:
\code{\link{as.data.frame}},
\code{\link[=as.list]{as.list()}},
\code{\link[=labels]{labels()}},
\code{\link{subset}}
}
\author{
N. Frerebeau
}
\concept{mutators}
