% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{ksarakil}
\alias{ksarakil}
\title{Ksâr 'Akil Radiocarbon Dates}
\format{
A \code{\link{data.frame}} with 16 rows and 5 variables:
\describe{
\item{code}{Laboratory code.}
\item{date}{Radiocarbon date (year BP).}
\item{error}{Radiocarbon error (year).}
\item{layer}{Stratigraphic layer.}
\item{phase}{Chronological phase.}
}
}
\source{
Bosch, M. D., Mannino, M. A., Prendergast, A. L., O'Connell, T. C.,
Demarchi, B., Taylor, S. M., Niven, L., van der Plicht, J. and Hublin, J.-J.
(2015). New Chronology for Ksâr 'Akil (Lebanon) Supports Levantine Route of
Modern Human Dispersal into Europe. \emph{Proceedings of the National Academy of
Sciences} 112(25): 7683-8. \doi{10.1073/pnas.1501529112}.
}
\usage{
ksarakil
}
\description{
Ksâr 'Akil Radiocarbon Dates
}
\concept{datasets}
\keyword{datasets}
